@@ -1,3 +1,5 @@
+#!/usr/bin/python
+# -*- coding: utf-8 -*-
 import sys
 
 import pandas as pd
@@ -29,7 +31,7 @@ class DataAccess:
             cursor = conn.cursor()
             cursor.execute(sql)
             pdf = pd.DataFrame(cursor.fetchall())
-            sdf = cf.build_spark_context().createDataFrame(pdf)
+            sdf = cf.build_sql_context().createDataFrame(pdf)
         except psycopg2.DatabaseError, exception:
             print (exception)
             sys.exit(1)
