@@ -6,7 +6,7 @@ import ConfigParser
 from pyspark import SparkConf
 
 curr_dir = os.path.dirname(os.path.realpath(__file__))
-relative_path = "\\..\\..\\..\\..\\resources"
+relative_path = "\\..\\..\\..\\resources"
 
 
 def load(filename):
@@ -26,3 +26,9 @@ def buildconfig(filename):
     config = ConfigParser.RawConfigParser()
     config.read(filepath)
     return config
+
+
+def build_config(file_path):
+    config = ConfigParser.RawConfigParser()
+    config.read(file_path)
+    return config
